@@ -3,8 +3,7 @@ use crate::{
     utils::SWAY_GIT_TAG,
 };
 use anyhow::Result;
-use forc_pkg::{check_program_type, manifest_file_missing, Manifest};
-use forc_util::find_manifest_dir;
+use forc_pkg::ManifestFile;
 use serde_json::{json, Value};
 use std::fs::File;
 use std::path::PathBuf;
@@ -16,10 +15,8 @@ pub fn build(command: JsonAbiCommand) -> Result<Value> {
     } else {
         std::env::current_dir()?
     };
-    let manifest_dir =
-        find_manifest_dir(&curr_dir).ok_or_else(|| manifest_file_missing(curr_dir))?;
-    let manifest = Manifest::from_dir(&manifest_dir, SWAY_GIT_TAG)?;
-    check_program_type(&manifest, manifest_dir, TreeType::Contract)?;
+    let manifest = ManifestFile::from_dir(&curr_dir, SWAY_GIT_TAG)?;
+    manifest.check_program_type(TreeType::Contract)?;
 
     let build_command = BuildCommand {
         path: command.path,
