@@ -1,14 +1,14 @@
 /// We intentionally don't construct this using [serde]'s default deserialization so we get
 /// the chance to insert some helpful comments and nicer formatting.
 pub(crate) fn default_manifest(project_name: &str, entry_type: &str) -> String {
-    let real_name = whoami::realname();
+    let author = get_author();
 
     format!(
         r#"[project]
-authors = ["{real_name}"]
+name = "{project_name}"
+authors = ["{author}"]
 entry = "{entry_type}"
 license = "Apache-2.0"
-name = "{project_name}"
 
 [dependencies]
 "#
@@ -19,21 +19,21 @@ name = "{project_name}"
 /// It includes necessary packages to make the Rust-based
 /// tests work.
 pub(crate) fn default_tests_manifest(project_name: &str) -> String {
-    let real_name = whoami::realname();
+    let author = get_author();
 
     format!(
         r#"[project]
-authors = ["{real_name}"]
-edition = "2021"
-license = "Apache-2.0"
 name = "{project_name}"
 version = "0.1.0"
+authors = ["{author}"]
+edition = "2021"
+license = "Apache-2.0"
 
 [dependencies]
 fuel-gql-client = {{ version = "0.6", default-features = false }}
 fuel-tx = "0.9"
-fuels-abigen-macro = "0.10"
-fuels = "0.10"
+fuels = "0.12"
+fuels-abigen-macro = "0.12"
 rand = "0.8"
 tokio = {{ version = "1.12", features = ["rt", "macros"] }}
 
@@ -95,7 +95,7 @@ fn main() -> bool {
 pub(crate) fn default_test_program(project_name: &str) -> String {
     format!(
         "{}{}{}{}{}",
-        r#"use fuel_tx::{ContractId, Salt};
+        r#"use fuel_tx::ContractId;
 use fuels_abigen_macro::abigen;
 use fuels::prelude::*;
 use fuels::test_helpers;
@@ -107,10 +107,9 @@ abigen!(MyContract, "out/debug/"#,
 
 async fn get_contract_instance() -> (MyContract, ContractId) {
     // Deploy the compiled contract
-    let salt = Salt::from([0u8; 32]);
     let compiled = Contract::load_sway_contract("./out/debug/"#,
         project_name,
-        r#".bin", salt).unwrap();
+        r#".bin").unwrap();
 
     // Launch a local network and deploy the contract
     let (provider, wallet) = test_helpers::setup_test_provider_and_wallet().await;
@@ -140,6 +139,10 @@ target
     .into()
 }
 
+fn get_author() -> String {
+    std::env::var(sway_utils::FORC_INIT_MANIFEST_AUTHOR).unwrap_or_else(|_| whoami::realname())
+}
+
 #[test]
 fn parse_default_manifest() {
     use sway_utils::constants::MAIN_ENTRY;
